@@ -6,17 +6,19 @@ def is_valid_function(obj: Any) -> bool:
     return isfunction(obj) or ismethod(obj)
 
 
-def stripdeco(obj: Callable, depth: int = None) -> Callable:
-    if not is_valid_function(obj=obj):
-        return obj
+def stripdeco(obj: Any, depth: int = None, **kwargs) -> Callable:
+    if not is_valid_function(obj=obj) or depth and depth == 0:
+        return obj()
 
-    if depth == 0:
-        return obj
+    try:
+        self = obj.__self__
+    except AttributeError:
+        pass
 
     while True:
         if depth is not None:
             if depth <= 0:
-                return obj
+                break
             else:
                 depth -= 1
 
@@ -25,7 +27,10 @@ def stripdeco(obj: Callable, depth: int = None) -> Callable:
         except TypeError:
             break
 
-    return obj
+    try:
+        return obj(**kwargs)
+    except TypeError:
+        return obj(self, **kwargs)
 
 
 __all__ = ["stripdeco"]
